isitpangram package
===================

Submodules
----------

isitpangram.cli module
----------------------

.. automodule:: isitpangram.cli
    :members:
    :undoc-members:
    :show-inheritance:

isitpangram.isitpangram module
------------------------------

.. automodule:: isitpangram.isitpangram
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: isitpangram
    :members:
    :undoc-members:
    :show-inheritance:
